@@ -12,7 +12,7 @@ use Carp;
 
 use base qw( Net::Async::HTTP::Server );
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use HTTP::Response;
 
@@ -214,7 +214,10 @@ sub on_request
       elsif( ref $body eq "ARRAY" ) {
          unless( $has_content_length ) {
             my $len = 0;
-            $len += length $_ for @$body;
+            my $found_undef;
+            $len += length( $_ // ( $found_undef++, "" ) ) for @$body;
+            carp "Found undefined value in PSGI body" if $found_undef;
+
             $response->content_length( $len );
          }
 
