@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2015 -- leonerd@leonerd.org.uk
 
 package Net::Async::HTTP::Server::Protocol;
 
@@ -9,11 +9,10 @@ use strict;
 use warnings;
 use base qw( IO::Async::Stream );
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Carp;
-
-use Net::Async::HTTP::Server::Request;
+use Scalar::Util qw( weaken );
 
 use HTTP::Request;
 
@@ -41,7 +40,9 @@ sub on_read
 
       $request->add_content( substr( $$buffref, 0, $request_body_len, "" ) );
 
-      push @{ $self->{requests} }, my $req = Net::Async::HTTP::Server::Request->new( $self, $request );
+      push @{ $self->{requests} }, my $req = $self->parent->make_request( $self, $request );
+      weaken( $self->{requests}[-1] );
+
       $self->parent->_received_request( $req );
 
       return undef;
@@ -52,7 +53,7 @@ sub on_closed
 {
    my $self = shift;
 
-   $_->_close for @{ $self->{requests} };
+   $_ and $_->_close for @{ $self->{requests} };
    undef @{ $self->{requests} };
 }
 
@@ -63,6 +64,7 @@ sub _flush_requests
    my $queue = $self->{requests};
    while( @$queue ) {
       my $req = $queue->[0];
+      $req or shift @$queue, next;
 
       my $is_done = $req->_write_to_stream( $self );
 
