@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2015 -- leonerd@leonerd.org.uk
 
 package Net::Async::HTTP::Server::Request;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Carp;
 
@@ -210,8 +210,9 @@ sub write_chunk
    my ( $data ) = @_;
 
    return if $self->{is_closed};
+   return unless my $len = length $data; # Must not write zero-byte chunks
 
-   $self->write( sprintf "%X$CRLF%s$CRLF", length $data, $data );
+   $self->write( sprintf "%X$CRLF%s$CRLF", $len, $data );
 }
 
 =head2 $request->done
